% Lösung der Übungsaufgabe 3.4

% Vorgaben (Aufgabenstellung)
R = 5;        % Ohm
L = 1e-3;     % H
C = 10e-6;    % F
u_s = 10;     % V
phi0 = pi/4;  % Radiant 
f = 1000;     % Hz
disp("Vorgaben");
disp(["  R  = ",num2str(R)," Ohm"]);
disp(["  L  = ",num2str(L*1e3)," mH"]);
disp(["  C  = ",num2str(C*1e6)," uF"]);
disp([" u_s = ",num2str(u_s)," V"]);
disp(["phi0 = ",num2str(phi0*180/pi),"°"]);
disp(["  f  = ",num2str(f)," Hz"]);
disp(" ");

% Komplexe Amplitude der Spannung u0(t)
U0 = u_s*exp(j*phi0)/sqrt(2);
disp("Komplexe Amplitude der Spannung u0(t)");
disp([" U0  = (",num2str(U0),") V"]);
disp(["|U0| = ",num2str(abs(U0))," V"]);
disp(["phi0 = ",num2str(angle(U0)*180/pi),"°"]);
disp(" ");

% Reaktanzen XL, XC und Impedanz Z
XL = 2*pi*f*L;
XC = -1/(2*pi*f*C);
Z = R+j*(XL+XC);
disp("Reaktanzen XL, XC und Impedanz Z");
disp([" XL  = ",num2str(XL)," Ohm"]);
disp([" XC  = ",num2str(XC)," Ohm"]);
disp(["  Z  = (",num2str(Z),") Ohm"]);
disp([" |Z| = ",num2str(abs(Z))," Ohm"]);
disp([" phi = ",num2str(angle(Z)*180/pi),"°"]);
disp(" ");

% Berechnung des Stromes
I = U0/Z;
i_s = abs(I)*sqrt(2);
disp("Berechnung des Stromes");
disp(["    I  = (",num2str(I*1e3),") mA"]);
disp(["   |I| = ",num2str(abs(I)*1e3)," mA  (Effektivwert)"]);
disp(["arg{I} = ",num2str(angle(I)*180/pi),"°"]);
disp(["   i_s = ",num2str(i_s*1e3)," mA  (Spitzenwert)"]);
disp(["  phii = ",num2str(angle(I)*180/pi),"°"]);
disp(" ");

% Berechnung der Spannungen
UR = R*I;
UL = j*XL*I;
UC = j*XC*I;
disp("Berechnung der Spannungen");
disp([" UR  = (",num2str(UR),") V"]);
disp(["|UR| = ",num2str(abs(UR))," V"]);
disp(["phiR = ",num2str(angle(UR)*180/pi),"°"]);
disp([" UL  = (",num2str(UL),") V"]);
disp(["|UL| = ",num2str(abs(UL))," V"]);
disp(["phiL = ",num2str(angle(UL)*180/pi),"°"]);
disp([" UC  = (",num2str(UC),") V"]);
disp(["|UC| = ",num2str(abs(UC))," V"]);
disp(["phiC = ",num2str(angle(UC)*180/pi),"°"]);
disp(" ");

% Resonanzfrequenz
f0 = 1/(2*pi*sqrt(L*C));
disp("Resonanzfrequenz");
disp([" f0  = ",num2str(f0)," Hz"]);
disp(" ");

% Reaktanzen und Impedanz bei Resonanzfrequenz
XL0 = 2*pi*f0*L;
XC0 = -1/(2*pi*f0*C);
Z0 = R+j*(XL0+XC0);
disp("Reaktanzen XL0, XC0 und Impedanz Z0 bei Resonanzfrequenz");
disp(["  XL0   = ",num2str(XL0)," Ohm"]);
disp(["  XC0   = ",num2str(XC0)," Ohm"]);
disp(["   Z0   = ",num2str(Z0)," Ohm"]);
disp(["  |Z0|  = ",num2str(abs(Z0))," Ohm"]);
disp(["arg{Z0} = ",num2str(angle(Z0)*180/pi),"°"]);
disp(" ");

% Strom bei Resonanzfrequenz
I0 = U0/Z0;
disp("Strom I0 bei Resonanzfrequenz");
disp(["    I0  = (",num2str(I0),") A"]);
disp(["   |I0| = ",num2str(abs(I0))," A  (Effektivwert)"]);
disp(["arg{I0} = ",num2str(angle(I0)*180/pi),"°"]);
disp(" ");

% =========================================================
% Funktion zur grafischen Darstellung eines Zeigers 
function pX = makepointer(x,s)
x = x(:);
d = x*s./abs(x);
pX = [zeros(length(x),1),x,x-d*(1+j/2),x,x-d*(1-j/2)].';
endfunction
% =========================================================

% Erzeugung der Zeiger (Linie und Pfeilspitze)
Zmax = 10; % Ohm  (Skalierung des Zeigerdiagramms der Impedanzen)
Umax = 10; % V    (Skalierung des Zeigerdiagramms der Spannungen)
% Impedanzen
pZ = makepointer(Z,Zmax/20);
pR = makepointer(R,Zmax/20);
pXL = makepointer(j*XL,Zmax/20);
pXC = makepointer(j*XC,Zmax/20);
% Spannungen
pU0 = makepointer(U0,Umax/20);
pUR = makepointer(UR,Umax/20);
pUC = makepointer(UC,Umax/20);
pUL = makepointer(UL,Umax/20);

% Darstellung des Zeigerdiagramms der Impedanzen
hFig1 = figure("Name","Zeigerdiagramm der Impedanzen");
hPlot1 = plot(pZ,"k",pR,"r",pXL-Zmax/100,"b",pXL(2)+pXC+Zmax/100,"g");
% Der Zeiger pXL wird leicht nach links versetzt, der Zeiger pXC wird
% leicht nach rechts versetzt und beginnt an der Zeigerspitze von pXL.  
axis([-Zmax,Zmax,-Zmax,Zmax]);
axis square;
grid on;
title("\\bf Zeigerdiagramm der Impedanzen","FontSize",14);
xlabel("Re\\{Z\\} / \\Omega","FontSize",12);
ylabel("Im\\{Z\\} / \\Omega","FontSize",12);
legend(hPlot1,"Z","R","X_L","X_C","location","southeastoutside");

% Darstellung des Zeigerdiagramms der Spannungen
hFig2 = figure("Name","Zeigerdiagramm der Spannungen");
hPlot2 = plot(pU0,"k",pUR,"r",pUL,"b",pUC,"g");
axis([-Umax,Umax,-Umax,Umax]);
axis square;
grid on;
title("\\bf Zeigerdiagramm der Spannungen","FontSize",14);
xlabel("Re\\{U\\} / V","FontSize",12);
ylabel("Im\\{U\\} / V","FontSize",12);
legend(hPlot2,"U_0","U_R","U_L","U_C","location","southeastoutside");


