% Lösung der Übungsaufgabe 3.5

% Vorgaben (Aufgabenstellung)
R = 1e3;      % Ohm
L = 2.2e-3;   % H
C = 1.8e-9;   % F
disp("Vorgaben");
disp(["  R  = ",num2str(R)," Ohm"]);
disp(["  L  = ",num2str(L*1e3)," mH"]);
disp(["  C  = ",num2str(C*1e9)," nF"]);
disp(" ");

% Resonanzfrequenz
f0 = 1/(2*pi*sqrt(L*C));
disp("Resonanzfrequenz");
disp(["  f0 = ",num2str(f0*1e-3)," kHz"]);
disp(" ");

% Grenzen des Darstellungsbereichs
fmin = 0;
fmax = 5*round(f0*1e-3)*1e3;

% Festlegung der Stützstellen
N = 200;
n = 0:(N-1);

% Frequenzachse erstellen
f = n*(fmax-fmin)/(N-1)+fmin;

% Berechnung von Admittanz und Impedanz
Y = 1/R+j*2*pi*f*C+1./(j*2*pi*f*L);
Z = 1./Y;

% Darstellung des Scheinleitwerts
hFig1 = figure("Name","Scheinleitwert");
hPlot1 = plot(f*1e-3,abs(Y)*1e3,"b"); % f in kHz, |Y| in mS
grid on;
title("\\bf Scheinleitwert über der Frequenz","FontSize",14);
xlabel("f / kHz","FontSize",12);
ylabel("|Y| / mS","FontSize",12);

% Darstellung des Scheinwiderstands
hFig2 = figure("Name","Scheinwiderstand");
hPlot2 = plot(f*1e-3,abs(Z)*1e-3,"r"); % f in kHz, |Z| in kOhm
grid on;
title("\\bf Scheinwiderstand über der Frequenz","FontSize",14);
xlabel("f / kHz","FontSize",12);
ylabel("|Z| / k\\Omega","FontSize",12);

% Admittanz und Blindleitwerte bei f0/2, f0 und 2f0
f = [f0/2,f0,2*f0];
BC = 2*pi*f*C;
BL = -1./(2*pi*f*L);
Y = 1/R+j*(BC+BL);
disp("Blindleitwerte und Admittanz bei f0/2, f0 und 2f0");
disp("f/kHz\tBC/mS\tBL/mS\tY/mS");
for i=1:length(f)
  disp([num2str(f(i)*1e-3,4),"\t",num2str(BC(i)*1e3,4),"\t",...
        num2str(BL(i)*1e3,4),"\t",num2str(Y(i)*1e3,4)]);
endfor
disp(" ");

% =========================================================
% Funktion zur grafischen Darstellung eines Zeigers 
function pX = makepointer(x,s)
x = x(:);
d = x*s./abs(x);
pX = [zeros(length(x),1),x,x-d*(1+j/2),x,x-d*(1-j/2)].';
endfunction
% =========================================================

% Erzeugung der Zeiger (Linie und Pfeilspitze)
Ymax = 2e-3; % S  (Skalierung des Zeigerdiagramms der Admittanzen)
% Admittanz bei f = f0/2
pY1 = makepointer(Y(1),Ymax/20);
pG1 = makepointer(1/R,Ymax/20);
pBC1 = makepointer(j*BC(1),Ymax/20);
pBL1 = makepointer(j*BL(1),Ymax/20);
% Admittanz bei f = f0
pY2 = makepointer(Y(2),Ymax/20);
pG2 = makepointer(1/R,Ymax/20);
pBC2 = makepointer(j*BC(2),Ymax/20);
pBL2 = makepointer(j*BL(2),Ymax/20);
% Admittanz bei f = 2f0
pY3 = makepointer(Y(3),Ymax/20);
pG3 = makepointer(1/R,Ymax/20);
pBC3 = makepointer(j*BC(3),Ymax/20);
pBL3 = makepointer(j*BL(3),Ymax/20);

% Darstellung des Zeigerdiagramms der Admittanzen bei f = f0/2
hFig3 = figure("Name","Zeigerdiagramm der Admittanzen bei f = f0/2");
hPlot3 = plot(pY1*1e3,"k",pG1*1e3,"r",(pBL1-Ymax/100)*1e3,"b",...
         (pBL1(2)+pBC1+Ymax/100)*1e3,"g");
% Der Zeiger pBL1 wird leicht nach links versetzt, der Zeiger pBC1 wird
% leicht nach rechts versetzt und beginnt an der Zeigerspitze von pBL1.  
axis([-Ymax,Ymax,-Ymax,Ymax]*1e3);
axis square;
grid on;
title("\\bf Zeigerdiagramm der Admittanzen bei f = f0/2","FontSize",14);
xlabel("Re\\{Y\\} / mS","FontSize",12);
ylabel("Im\\{Y\\} / mS","FontSize",12);
legend(hPlot3,"Y","G","B_L","B_C","location","southeastoutside");

% Darstellung des Zeigerdiagramms der Admittanzen bei f = f0
hFig4 = figure("Name","Zeigerdiagramm der Admittanzen bei f = f0");
hPlot4 = plot((pY2+j*Ymax/100)*1e3,"k",(pG2-j*Ymax/100)*1e3,"r",...
              (pBL2-Ymax/100)*1e3,"b",(pBL2(2)+pBC2+Ymax/100)*1e3,"g");
% Der Zeiger pBL2 wird leicht nach links versetzt, der Zeiger pBC2 wird
% leicht nach rechts versetzt und beginnt an der Zeigerspitze von pBL2.  
% Der Zeiger pY2 wird leicht nach oben und der Zeiger pG2 wird leicht 
% nach unten versetzt.
axis([-Ymax,Ymax,-Ymax,Ymax]*1e3);
axis square;
grid on;
title("\\bf Zeigerdiagramm der Admittanzen bei f = f0","FontSize",14);
xlabel("Re\\{Y\\} / mS","FontSize",12);
ylabel("Im\\{Y\\} / mS","FontSize",12);
legend(hPlot4,"Y","G","B_L","B_C","location","southeastoutside");

% Darstellung des Zeigerdiagramms der Admittanzen bei f = 2f0
hFig5 = figure("Name","Zeigerdiagramm der Admittanzen bei f = 2f0");
hPlot5 = plot(pY3*1e3,"k",pG3*1e3,"r",(pBL3-Ymax/100)*1e3,"b",...
         (pBL3(2)+pBC3+Ymax/100)*1e3,"g");
% Der Zeiger pBL3 wird leicht nach links versetzt, der Zeiger pBC3 wird
% leicht nach rechts versetzt und beginnt an der Zeigerspitze von pBL3.  
axis([-Ymax,Ymax,-Ymax,Ymax]*1e3);
axis square;
grid on;
title("\\bf Zeigerdiagramm der Admittanzen bei f = 2f0","FontSize",14);
xlabel("Re\\{Y\\} / mS","FontSize",12);
ylabel("Im\\{Y\\} / mS","FontSize",12);
legend(hPlot5,"Y","G","B_L","B_C","location","southeastoutside");

