% Lösung der Übungsaufgabe 3.6

% Vorgaben (Aufgabenstellung)
R1 = 100;     % Ohm
R2 = 10e3;    % Ohm
L  = 22e-3;   % H
C  = 470e-9;  % F
u0 = 5;       % V
f0 = 1e3;     % Hz
disp("Vorgaben");
disp(["  R1 = ",num2str(R1)," Ohm"]);
disp(["  R2 = ",num2str(R2)," Ohm"]);
disp(["  L  = ",num2str(L*1e3)," mH"]);
disp(["  C  = ",num2str(C*1e9)," nF"]);
disp(["  u0 = ",num2str(u0)," V"]);
disp(["  f0 = ",num2str(f0*1e-3)," kHz"]);
disp(" ");

% =========================================================
% Funktion zur Berechnung der Impedanz
function Z = impedanz(f,R1,R2,L,C)
w = 2*pi*f;
Z = R2*(R1+j*w*L)./(R1+R2-(w.^2)*R2*L*C+j*w*(L+R1*R2*C));
endfunction
% =========================================================

% Impedanz und Blindwiderstände
fi  = [100,500,1e3,2e3,4e3,5e3]; % Hz
Z   = impedanz(fi,R1,R2,L,C);
XL  = 2*pi*fi*L;
XC  = -1./(2*pi*fi*C);
ZZ  = abs(Z); % Scheinwiderstand
phi = angle(Z)*180/pi; % Winkel in Grad
disp("Impedanz und Blindwiderstände");
disp("f/kHz\tXL/Ohm\tXC/Ohm\tZ/Ohm\t\t|Z|/Ohm\tphi/Grad");
for i=1:length(fi)
  disp([num2str(fi(i)*1e-3,4),"\t",num2str(XL(i),4),"\t",...
        num2str(XC(i),4),"\t",num2str(Z(i),5),"\t",...
        num2str(ZZ(i),5),"\t",num2str(phi(i),4)]);
endfor
disp(" ");

% Rein reele Impedanz (Frequenzen)
w0 = sqrt((R2*L*(R1+R2)-R1*R2*(L+R1*R2*C))/((R2^2)*(L^2)*C));
wi = [0,Inf,w0,-w0];
Zi = impedanz(wi/(2*pi),R1,R2,L,C); % Reelle Impedanz
disp("Impedanz wird rein reell bei den Frequenzen");
disp("omega/s⁻¹\tf/Hz\t\tZ/Ohm");
for i=1:length(wi)
  disp([num2str(wi(i),4),"\t\t",num2str(wi(i)/(2*pi),5),"\t\t",...
        num2str(Zi(i),4)]);
endfor
disp(" ");

% Komplexe Amplitude
U0 = u0/sqrt(2);
disp("Komplexe Amplitude");
disp(["  U0 = ",num2str(U0)," V (arg U0 = 0°)"]);
disp(" ");

% Strom und Quellspannung in Phase
disp("Wahl von Z0");
Z = impedanz(f0,R1,R2,L,C);
Z0 = -j*imag(Z);
C0 = -1/(2*pi*f0*imag(Z0));
disp(["Bei f0 = ",num2str(f0*1e-3)," kHz gilt"]);
disp(["  Z = ",num2str(Z)," Ohm"]);
disp([" Z0 = ",num2str(Z0)," Ohm (Realteil ist beliebig)"]);
disp("Realisierung durch Kapazität");
disp([" C0 = ",num2str(C0*1e6)," uF"]);
disp(" ");

% Grenzen des Darstellungsbereichs
fmin = 0;
fmax = 5e3; % Hz

% Festlegung der Stützstellen
N = 200;
n = 0:(N-1);

% Frequenzachse erstellen
f = n*(fmax-fmin)/(N-1)+fmin;

% Impedanz
Z = impedanz(f,R1,R2,L,C);

% Darstellung des Scheinwiderstands
hFig1 = figure("Name","Scheinwiderstand");
hPlot1 = plot(f*1e-3,abs(Z),"r"); % f in kHz, |Z| in Ohm
grid on;
title("\\bf Scheinwiderstand über der Frequenz","FontSize",14);
xlabel("f / kHz","FontSize",12);
ylabel("|Z| / \\Omega","FontSize",12);

% Darstellung des Winkels
hFig2 = figure("Name","Winkel der Impedanz");
hPlot2 = plot(f*1e-3,angle(Z)*180/pi,"b"); % f in kHz, arg(Z) in Grad
grid on;
title("\\bf Winkel der Impedanz über der Frequenz","FontSize",14);
xlabel("f / kHz","FontSize",12);
ylabel("arg(Z) / Grad","FontSize",12);
